@@ -1,54 +1,18 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <sys/types.h>
 
 #include <ctime>
 #include <regex>
-
 #include <rak/algorithm.h>
-#include <rak/functional.h>
 #include <torrent/utils/log.h>
 
 #include "core/manager.h"
 #include "core/view_manager.h"
+#include "display/canvas.h"
 #include "ui/root.h"
 #include "ui/download_list.h"
+#include "display/color_map.h"
 #include "rpc/parse.h"
 
 #include "globals.h"
@@ -63,7 +27,7 @@ apply_view_filter_on(const torrent::Object::list_type& args) {
     throw torrent::input_error("Too few arguments.");
 
   const std::string& name = args.front().as_string();
-  
+
   if (name.empty())
     throw torrent::input_error("First argument must be a string.");
 
@@ -130,11 +94,12 @@ apply_view_set(const torrent::Object::list_type& args) {
 //   if (args.front().as_string() == "main")
 //     control->ui()->download_list()->set_view(*itr);
 //   else
-    throw torrent::input_error("No such target.");
+
+  throw torrent::input_error("No such target.");
 }
 
 torrent::Object
-apply_print(rpc::target_type target, const torrent::Object& rawArgs) {
+apply_print([[maybe_unused]] rpc::target_type target, const torrent::Object& rawArgs) {
   char buffer[1024];
   rpc::print_object(buffer, buffer + 1024, &rawArgs, 0);
 
@@ -143,7 +108,7 @@ apply_print(rpc::target_type target, const torrent::Object& rawArgs) {
 }
 
 torrent::Object
-apply_cat(rpc::target_type target, const torrent::Object& rawArgs) {
+apply_cat([[maybe_unused]] rpc::target_type target, const torrent::Object& rawArgs) {
   std::string result;
 
   rpc::print_object_std(&result, &rawArgs, 0);
@@ -151,7 +116,7 @@ apply_cat(rpc::target_type target, const torrent::Object& rawArgs) {
 }
 
 torrent::Object
-apply_value(rpc::target_type target, const torrent::Object::list_type& args) {
+apply_value([[maybe_unused]] rpc::target_type target, const torrent::Object::list_type& args) {
   if (args.size() < 1)
     throw torrent::input_error("'value' takes at least a number argument!");
   if (args.size() > 2)
@@ -219,7 +184,7 @@ apply_not(rpc::target_type target, const torrent::Object& rawArgs) {
 }
 
 torrent::Object
-apply_false(rpc::target_type target, const torrent::Object& rawArgs) {
+apply_false([[maybe_unused]] rpc::target_type target, [[maybe_unused]] const torrent::Object& rawArgs) {
   return (int64_t)0;
 }
 
@@ -234,10 +199,10 @@ apply_and(rpc::target_type target, const torrent::Object& rawArgs) {
         return (int64_t)false;
 
     } else if (itr->is_value()) {
-      if (!itr->as_value())      
+      if (!itr->as_value())
         return (int64_t)false;
 
-    } else {        
+    } else {
       // TODO: Switch to new versions that only accept the new command syntax.
       if (!as_boolean(rpc::parse_command_single(target, itr->as_string())))
         return (int64_t)false;
@@ -257,10 +222,10 @@ apply_or(rpc::target_type target, const torrent::Object& rawArgs) {
         return (int64_t)true;
 
     } else if (itr->is_value()) {
-      if (itr->as_value())      
+      if (itr->as_value())
         return (int64_t)true;
 
-    } else {        
+    } else {
       if (as_boolean(rpc::parse_command_single(target, itr->as_string())))
         return (int64_t)true;
     }
@@ -297,7 +262,7 @@ apply_cmp(rpc::target_type target, const torrent::Object::list_type& args) {
 
   if (result1.type() != result2.type())
     throw torrent::input_error("Type mismatch.");
-    
+
   switch (result1.type()) {
   case torrent::Object::TYPE_VALUE:  return result1.as_value() - result2.as_value();
   case torrent::Object::TYPE_STRING: return result1.as_string().compare(result2.as_string());
@@ -426,7 +391,7 @@ apply_to_time(const torrent::Object& rawArgs, int flags) {
     u = std::localtime(&t);
   else
     u = std::gmtime(&t);
-  
+
   if (u == NULL)
     return torrent::Object();
 
@@ -442,7 +407,9 @@ apply_to_time(const torrent::Object& rawArgs, int flags) {
 
 torrent::Object
 apply_to_elapsed_time(const torrent::Object& rawArgs) {
-  uint64_t arg = cachedTime.seconds() - rawArgs.as_value();
+  auto cached_seconds = torrent::this_thread::cached_seconds().count();
+
+  uint64_t arg = cached_seconds - rawArgs.as_value();
 
   char buffer[48];
   snprintf(buffer, 48, "%2d:%02d:%02d", (int)(arg / 3600), (int)((arg / 60) % 60), (int)(arg % 60));
@@ -469,7 +436,7 @@ apply_to_mb(const torrent::Object& rawArgs) {
 torrent::Object
 apply_to_xb(const torrent::Object& rawArgs) {
   char buffer[48];
-  int64_t arg = rawArgs.as_value();  
+  int64_t arg = rawArgs.as_value();
 
   if (arg < (int64_t(1000) << 10))
     snprintf(buffer, 48, "%5.1f KB", (double)arg / (int64_t(1) << 10));
@@ -485,7 +452,7 @@ apply_to_xb(const torrent::Object& rawArgs) {
 
 torrent::Object
 apply_to_throttle(const torrent::Object& rawArgs) {
-  int64_t arg = rawArgs.as_value();  
+  int64_t arg = rawArgs.as_value();
   if (arg < 0)
     return "---";
   else if (arg == 0)
@@ -583,7 +550,7 @@ cmd_view_size_not_visible(const torrent::Object::string_type& args) {
 torrent::Object
 cmd_view_persistent(const torrent::Object::string_type& args) {
   core::View* view = *control->view_manager()->find_throw(args);
-  
+
   if (!view->get_filter().is_empty() || !view->event_added().is_empty() || !view->event_removed().is_empty())
     throw torrent::input_error("Cannot set modified views as persitent.");
 
@@ -640,8 +607,9 @@ apply_elapsed_less(const torrent::Object::list_type& args) {
     throw torrent::input_error("Wrong argument count.");
 
   int64_t start_time = rpc::convert_to_value(args.front());
+  auto cached_seconds = torrent::this_thread::cached_seconds().count();
 
-  return (int64_t)(start_time != 0 && rak::timer::current_seconds() - start_time < rpc::convert_to_value(args.back()));
+  return (int64_t)(start_time != 0 && cached_seconds - start_time < rpc::convert_to_value(args.back()));
 }
 
 torrent::Object
@@ -650,8 +618,9 @@ apply_elapsed_greater(const torrent::Object::list_type& args) {
     throw torrent::input_error("Wrong argument count.");
 
   int64_t start_time = rpc::convert_to_value(args.front());
+  auto cached_seconds = torrent::this_thread::cached_seconds().count();
 
-  return (int64_t)(start_time != 0 && rak::timer::current_seconds() - start_time > rpc::convert_to_value(args.back()));
+  return (int64_t)(start_time != 0 && cached_seconds - start_time > rpc::convert_to_value(args.back()));
 }
 
 inline std::vector<int64_t>
@@ -796,6 +765,13 @@ cmd_status_throttle_names(bool up, const torrent::Object::list_type& args) {
   return torrent::Object();
 }
 
+torrent::Object
+apply_set_color(int color_id, const torrent::Object::string_type& color_str) {
+  control->object_storage()->set_str_string(display::color_vars[color_id], color_str);
+  display::Canvas::build_colors();
+  return torrent::Object();
+}
+
 void
 initialize_command_ui() {
   CMD2_VAR_STRING("keys.layout", "qwerty");
@@ -843,6 +819,8 @@ initialize_command_ui() {
   CMD2_VAR_VALUE ("ui.throttle.global.step.medium", 50);
   CMD2_VAR_VALUE ("ui.throttle.global.step.large",  500);
 
+  CMD2_VAR_VALUE ("ui.focus.page_size", 0);
+
   CMD2_ANY_LIST  ("ui.status.throttle.up.set",   std::bind(&cmd_status_throttle_names, true, std::placeholders::_2));
   CMD2_ANY_LIST  ("ui.status.throttle.down.set", std::bind(&cmd_status_throttle_names, false, std::placeholders::_2));
 
@@ -893,4 +871,15 @@ initialize_command_ui() {
 
   CMD2_ANY_LIST ("elapsed.less",         std::bind(&apply_elapsed_less, std::placeholders::_2));
   CMD2_ANY_LIST ("elapsed.greater",      std::bind(&apply_elapsed_greater, std::placeholders::_2));
+
+  // Build set/get methods for all color definitions
+  for (int color_id = 1; color_id < display::RCOLOR_MAX; color_id++) {
+    control->object_storage()->insert_str(display::color_vars[color_id], "", rpc::object_storage::flag_string_type);
+    CMD2_ANY_STRING(std::string(display::color_vars[color_id]) + ".set", [color_id](const auto&, const auto& arg) {
+      return apply_set_color(color_id, arg);
+    });
+    CMD2_ANY(display::color_vars[color_id], [color_id](const auto&, const auto&) {
+      return control->object_storage()->get_str(display::color_vars[color_id]);
+    });
+  }
 }
