@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,8 +37,8 @@
 #ifndef RTORRENT_DISPLAY_TEXT_ELEMENT_H
 #define RTORRENT_DISPLAY_TEXT_ELEMENT_H
 
+#include <cinttypes>
 #include <vector>
-#include <inttypes.h>
 
 #include "display/canvas.h"
 #include "rpc/command_map.h"
@@ -51,8 +51,8 @@ public:
 
   static const extent_type extent_full   = ~extent_type();
 
-  TextElement() {}
-  virtual ~TextElement() {}
+  TextElement()          = default;
+  virtual ~TextElement() = default;
 
   // The last element must point to a valid memory location into which
   // the caller must write a '\0' to terminate the c string. The
