@@ -38,7 +38,6 @@
 
 #include <functional>
 #include <rak/algorithm.h>
-#include <rak/functional.h>
 #include <rak/path.h>
 
 #include <dirent.h>
@@ -50,10 +49,6 @@
 
 namespace input {
 
-PathInput::PathInput() :
-  m_showNext(false) {
-}
-
 bool
 PathInput::pressed(int key) {
   // Consider binding tab in m_bindings instead.
@@ -76,11 +71,11 @@ PathInput::pressed(int key) {
 struct _transform_filename {
   void operator () (utils::directory_entry& entry) {
 #ifdef __sun__
-    if (entry.d_type & S_IFDIR)
+    if (entry.s_type & S_IFDIR)
 #else
-    if (entry.d_type == DT_DIR)
+    if (entry.s_type == DT_DIR)
 #endif
-      entry.d_name += '/';
+      entry.s_name += '/';
   }
 };
 
@@ -105,7 +100,7 @@ PathInput::receive_do_complete() {
   if (r.first == r.second)
     return; // Show some nice colors here.
 
-  std::string base = rak::make_base<std::string>(r.first, r.second, rak::const_mem_ref(&utils::directory_entry::d_name));
+  std::string base = rak::make_base<std::string>(r.first, r.second, std::mem_fn(&utils::directory_entry::s_name));
 
   // Clear the path after the cursor to make this code cleaner. It's
   // not really nessesary to add the complexity just because someone
@@ -142,20 +137,24 @@ PathInput::find_last_delim() {
 
 inline bool
 find_complete_compare(const utils::directory_entry& complete, const std::string& base) {
-  return complete.d_name.compare(0, base.size(), base);
+  return complete.s_name.compare(0, base.size(), base);
 }
 
 inline bool
 find_complete_not_compare(const utils::directory_entry& complete, const std::string& base) {
-  return !complete.d_name.compare(0, base.size(), base);
+  return !complete.s_name.compare(0, base.size(), base);
 }
 
 PathInput::range_type
 PathInput::find_incomplete(utils::Directory& d, const std::string& f) {
   range_type r;
 
-  r.first  = std::find_if(d.begin(), d.end(), rak::bind2nd(std::ptr_fun(&find_complete_not_compare), f));
-  r.second = std::find_if(r.first,   d.end(), rak::bind2nd(std::ptr_fun(&find_complete_compare), f));
+  r.first  = std::find_if(d.begin(), d.end(), [f](const utils::directory_entry& de) { 
+      return find_complete_not_compare(de, f); 
+  });
+  r.second = std::find_if(r.first,   d.end(), [f](const utils::directory_entry& de) { 
+      return find_complete_compare(de, f); 
+  });
 
   return r;
 }
