@@ -1,39 +1,3 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #define __STDC_FORMAT_MACROS
@@ -47,10 +11,8 @@
 #include <torrent/http.h>
 #include <torrent/torrent.h>
 #include <torrent/exceptions.h>
-#include <torrent/poll.h>
 #include <torrent/data/chunk_utils.h>
 #include <torrent/utils/log.h>
-#include <rak/functional.h>
 #include <rak/error_number.h>
 
 #ifdef HAVE_BACKTRACE
@@ -136,7 +98,7 @@ load_session_torrents() {
     // Replace with session torrent flag.
     f->set_session(true);
     f->set_init_load(true);
-    f->slot_finished(std::bind(&rak::call_delete_func<core::DownloadFactory>, f));
+    f->slot_finished([f](){ delete f; });
     f->load(entries.path() + first->s_name);
     f->commit();
   }
@@ -151,22 +113,12 @@ load_arg_torrents(char** first, char** last) {
     // Replace with session torrent flag.
     f->set_start(true);
     f->set_init_load(true);
-    f->slot_finished(std::bind(&rak::call_delete_func<core::DownloadFactory>, f));
+    f->slot_finished([f](){ delete f; });
     f->load(*first);
     f->commit();
   }
 }
 
-static uint64_t
-client_next_timeout() {
-  if (taskScheduler.empty())
-    return (control->is_shutdown_started() ? rak::timer::from_milliseconds(100) : rak::timer::from_seconds(60)).usec();
-  else if (taskScheduler.top()->time() <= cachedTime)
-    return 0;
-  else
-    return (taskScheduler.top()->time() - cachedTime).usec();
-}
-
 static void
 client_perform() {
   // Use throw exclusively.
@@ -177,9 +129,6 @@ client_perform() {
     control->handle_shutdown();
 
   control->inc_tick();
-
-  cachedTime = rak::timer::current();
-  rak::priority_queue_perform(&taskScheduler, cachedTime);
 }
 
 int
@@ -189,18 +138,21 @@ main(int argc, char** argv) {
     // Temporary.
     setlocale(LC_ALL, "");
 
-    cachedTime = rak::timer::current();
+    auto random_seed = []() -> unsigned int {
+        auto current_time = torrent::utils::time_since_epoch();
 
-    // Initialize logging:
-    torrent::log_initialize();
-
-    control = new Control;
-    
-    unsigned int random_seed = cachedTime.seconds() ^ cachedTime.usec() ^ (getpid() << 16) ^ getppid();
+        return (getpid() << 16) ^ getppid() ^
+          torrent::utils::cast_seconds(current_time).count() ^ current_time.count();
+      }();
 
     srandom(random_seed);
     srand48(random_seed);
 
+    torrent::initialize_main_thread();
+    torrent::log_initialize();
+
+    control = new Control;
+
     SignalHandler::set_ignore(SIGPIPE);
     SignalHandler::set_handler(SIGINT,   std::bind(&Control::receive_normal_shutdown, control));
     SignalHandler::set_handler(SIGHUP,   std::bind(&Control::receive_normal_shutdown, control));
@@ -219,17 +171,14 @@ main(int argc, char** argv) {
     // platforms that do not properly pass signals to the target
     // threads. Use '--enable-interrupt-socket' when configuring
     // LibTorrent to enable this workaround.
-    if (torrent::thread_base::should_handle_sigusr1())
+    if (torrent::utils::Thread::should_handle_sigusr1())
       SignalHandler::set_handler(SIGUSR1, std::bind(&do_nothing));
 
     torrent::log_add_group_output(torrent::LOG_NOTICE, "important");
     torrent::log_add_group_output(torrent::LOG_INFO, "complete");
 
-    torrent::Poll::slot_create_poll() = std::bind(&core::create_poll);
-
     torrent::initialize();
-    torrent::main_thread()->slot_do_work() = std::bind(&client_perform);
-    torrent::main_thread()->slot_next_timeout() = std::bind(&client_next_timeout);
+    torrent::set_main_thread_slots(std::bind(&client_perform));
 
     worker_thread = new ThreadWorker();
     worker_thread->init_thread();
@@ -269,7 +218,7 @@ main(int argc, char** argv) {
        "method.insert = event.download.closed,multi|rlookup|static\n"
        "method.insert = event.download.resumed,multi|rlookup|static\n"
        "method.insert = event.download.paused,multi|rlookup|static\n"
-       
+
        "method.insert = event.download.finished,multi|rlookup|static\n"
        "method.insert = event.download.hash_done,multi|rlookup|static\n"
        "method.insert = event.download.hash_failed,multi|rlookup|static\n"
@@ -433,25 +382,26 @@ main(int argc, char** argv) {
     CMD2_REDIRECT        ("torrent_list_layout", "ui.torrent_list.layout.set");
 
     // Deprecated commands. Don't use these anymore.
+    //
+    // It has been so long that we now re-create these commands with the new (old by now) command
+    // call style, where the first argument is the target.
 
-    if (rpc::call_command_value("method.use_intermediate") == 1) {
-      CMD2_REDIRECT_GENERIC("execute", "execute2");
+    // if (rpc::call_command_value("method.use_intermediate") == 1) {
+    //   CMD2_REDIRECT_GENERIC("execute", "execute2");
 
-      CMD2_REDIRECT_GENERIC("schedule", "schedule2");
-      CMD2_REDIRECT_GENERIC("schedule_remove", "schedule_remove2");
+    //   CMD2_REDIRECT_GENERIC("schedule", "schedule2");
+    //   CMD2_REDIRECT_GENERIC("schedule_remove", "schedule_remove2");
 
-    } else if (rpc::call_command_value("method.use_intermediate") == 2) {
-      // Allow for use in config files, etc, just don't export it.
-      CMD2_REDIRECT_GENERIC_NO_EXPORT("execute", "execute2");
+    // } else if (rpc::call_command_value("method.use_intermediate") == 2) {
+    //   Allow for use in config files, etc, just don't export it.
+    //   CMD2_REDIRECT_GENERIC_NO_EXPORT("execute", "execute2");
 
-      CMD2_REDIRECT_GENERIC_NO_EXPORT("schedule", "schedule2");
-      CMD2_REDIRECT_GENERIC_NO_EXPORT("schedule_remove", "schedule_remove2");
-    }
+    //   CMD2_REDIRECT_GENERIC_NO_EXPORT("schedule", "schedule2");
+    //   CMD2_REDIRECT_GENERIC_NO_EXPORT("schedule_remove", "schedule_remove2");
+    // }
 
-#if LT_SLIM_VERSION != 1
-    if (rpc::call_command_value("method.use_deprecated")) {
-    }
-#endif
+    // if (rpc::call_command_value("method.use_deprecated") == 1) {
+    // }
 
     int firstArg = parse_options(argc, argv);
 
@@ -480,7 +430,9 @@ main(int argc, char** argv) {
     // session torrents are loaded before arg torrents.
     control->dht_manager()->load_dht_cache();
     load_session_torrents();
-    rak::priority_queue_perform(&taskScheduler, cachedTime);
+
+    // TODO: Check if this is required.
+    // rak::priority_queue_perform(&taskScheduler, cachedTime);
 
     load_arg_torrents(argv + firstArg, argv + argc);
 
@@ -494,7 +446,7 @@ main(int argc, char** argv) {
 
     rpc::commands.call_catch("event.system.startup_done", rpc::make_target(), "startup_done", "System startup_done event action failed: ");
 
-    torrent::thread_base::event_loop(torrent::main_thread());
+    torrent::utils::Thread::self()->event_loop();
 
     control->core()->download_list()->session_save();
     control->cleanup();
@@ -525,7 +477,7 @@ main(int argc, char** argv) {
 }
 
 void
-handle_sigbus(int signum, siginfo_t* sa, void* ptr) {
+handle_sigbus(int signum, siginfo_t* sa, [[maybe_unused]] void* ptr) {
   if (signum != SIGBUS)
     do_panic(signum);
 
@@ -605,7 +557,7 @@ do_panic(int signum) {
   std::stringstream output;
 
   output << "Caught " << SignalHandler::as_string(signum) << ", dumping stack:" << std::endl;
-  
+
 #ifdef HAVE_BACKTRACE
   void* stackPtrs[20];
 
@@ -619,7 +571,7 @@ do_panic(int signum) {
 #else
   output << "Stack dump not enabled." << std::endl;
 #endif
-  
+
   if (signum == SIGBUS)
     output << "A bus error probably means you ran out of diskspace." << std::endl;
 
@@ -643,6 +595,8 @@ print_help() {
   std::cout << std::endl;
   std::cout << "Usage: rtorrent [OPTIONS]... [FILE]... [URL]..." << std::endl;
   std::cout << "  -D                Enable deprecated commands" << std::endl;
+  std::cout << "  -I                Disable intermediate commands" << std::endl;
+  std::cout << "  -K                Allow intermediate commands without xmlrpc" << std::endl;
   std::cout << "  -h                Display this very helpful text" << std::endl;
   std::cout << "  -n                Don't try to load rtorrent.rc on startup" << std::endl;
   std::cout << "  -b <a.b.c.d>      Bind the listening socket to this IP" << std::endl;
