@@ -40,9 +40,8 @@
 #include <string>
 #include <cstring>
 
-#include "command_map.h"
-#include "exec_file.h"
 #include "xmlrpc.h"
+#include "rpc_manager.h"
 
 namespace core {
   class Download;
@@ -50,11 +49,6 @@ namespace core {
 
 namespace rpc {
 
-// Move to another file?
-extern CommandMap commands;
-extern XmlRpc     xmlrpc;
-extern ExecFile   execFile;
-
 typedef std::pair<torrent::Object, const char*> parse_command_type;
 
 // The generic parse command function, used by the rest. At some point
